################################
Frequently Asked Questions
################################

.. contents::
  :depth: 2
  :backlinks: entry

-------------------

***********************
Getting Help
***********************

**Where can I get help using Highcharts Core for Python?**

This documentation is a great place to start, but we're here to help!

.. include:: _support.rst

-----------------

.. _faq_licensing:

***********************
Licensing
***********************

**Is Highcharts Core for Python free?**

If you are evaluating the **Highcharts for Python Toolkit**, you are welcome 
to install this library and use it free of charge. 

However, if you are using it for professional purposes - either to use 
Highcharts for your work, or to build an application that integrates the library - 
then you have to pay for both Highcharts Core (JS) itself *and* for your right 
to use the **Highcharts for Python Toolkit**. 

You can purchase licenses for both from Highsoft A/S at: 
`https://shop.highcharts.com/ <https://shop.highcharts.com>`__.

**How much does Highcharts for Python cost?**

As a paid add-on to the Highcharts JavaScript libraries, the 
**Highcharts for Python Toolkit** toolkit is priced at 30% of the price you pay 
for your Highcharts JavaScript license/support contract.

**How do I license the Highcharts for Python Toolkit?**

Licensing is super easy! You can go to 
`https://shop.highcharts.com <https://shop.highcharts.com>`__ and fill out the 
form, and that's it!

----------------------

******************************
Open Source
******************************

**Is Highcharts for Python open source?**

Yes. The **Highcharts for Python Toolkit** toolkit is open source (but not free - 
see :ref:`licensing <faq_licensing>` above).

You are welcome to review the source code for any library in the toolkit on 
`Github <https://github.com/highcharts-for-python>`__, including for 
`Highcharts Core for Python <https://github.com/highcharts-for-python/highcharts-core>`__.

**Can I fork the toolkit or a library in the toolkit?**

.. warning::

  Remember that if you fork the library and make modifications to the source code, that means that we will *not* be able to provide support or technical assistance for you should you run into trouble. So you will ultimately depend on
  forks at your own risk!

Yes. You are welcome to fork any of our repositories from `Github <https://github.com/highcharts-for-python>`__, 
provided that you adhere to the terms of our :doc:`license`.

.. tip::

  Bear in mind that if you fork the repository, that does not mean you are allowed to use it for professional purposes. Even if forked, you still need a license to do so. You can purchase a license `here <https://shop.highcharts.com>`__.

**Can I contribute to the Highcharts for Python Toolkit?**

Absolutely! We encourage contributions to the toolkit from the community! For more information, please read our :doc:`Contributor Guide <contributing>`.

